summaryrefslogtreecommitdiffstats
path: root/lib/widgets/qcomboview.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'lib/widgets/qcomboview.cpp')
-rw-r--r--lib/widgets/qcomboview.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/lib/widgets/qcomboview.cpp b/lib/widgets/qcomboview.cpp
index 99ce12e4..4db96f46 100644
--- a/lib/widgets/qcomboview.cpp
+++ b/lib/widgets/qcomboview.cpp
@@ -88,7 +88,7 @@ void QComboViewData::updateLinedGeometry()
const TQPixmap *pix = combo->currentItem() ? combo->currentItem()->pixmap(0) : 0;
if ( pix && pix->width() < r.width() )
r.setLeft( r.left() + pix->width() + 4 );
- if ( r != ed->tqgeometry() )
+ if ( r != ed->geometry() )
ed->setGeometry( r );
}
@@ -269,7 +269,7 @@ void QComboView::setAutoResize( bool enable )
reimp
This implementation caches the size hint to avoid resizing when
- the contents change dynamically. To tqinvalidate the cached value
+ the contents change dynamically. To invalidate the cached value
call setFont().
*/
TQSize QComboView::sizeHint() const
@@ -385,7 +385,7 @@ void QComboView::setPalette( const TQPalette &palette )
void QComboView::setFont( const TQFont &font )
{
- d->sizeHint = TQSize(); // tqinvalidate size hint
+ d->sizeHint = TQSize(); // invalidate size hint
TQWidget::setFont( font );
d->listView()->setFont( font );
if (d->ed)
@@ -489,7 +489,7 @@ void QComboView::mousePressEvent( TQMouseEvent *e )
if ( arrowRect.contains( e->pos() ) ) {
d->arrowPressed = TRUE;
d->arrowDown = TRUE;
- tqrepaint( FALSE );
+ repaint( FALSE );
}
TQTimer::singleShot( 200, this, TQT_SLOT(internalClickTimeout()));
d->shortClick = TRUE;
@@ -808,7 +808,7 @@ void QComboView::popDownListView()
d->listView()->setCurrentItem( d->current );
if ( d->arrowDown ) {
d->arrowDown = FALSE;
- tqrepaint( FALSE );
+ repaint( FALSE );
}
d->poppedUp = FALSE;
}
@@ -908,12 +908,12 @@ bool QComboView::eventFilter( TQObject *object, TQEvent *event )
if ( arrowRect.contains( comboPos ) ) {
if ( !d->arrowDown ) {
d->arrowDown = TRUE;
- tqrepaint( FALSE );
+ repaint( FALSE );
}
} else {
if ( d->arrowDown ) {
d->arrowDown = FALSE;
- tqrepaint( FALSE );
+ repaint( FALSE );
}
}
}
@@ -948,7 +948,7 @@ bool QComboView::eventFilter( TQObject *object, TQEvent *event )
d->arrowPressed = FALSE;
if ( d->arrowDown ) {
d->arrowDown = FALSE;
- tqrepaint( FALSE );
+ repaint( FALSE );
}
}
}
@@ -1333,7 +1333,7 @@ bool QComboView::autoCompletion() const
*/
void QComboView::styleChange( TQStyle& s )
{
- d->sizeHint = TQSize(); // tqinvalidate size hint...
+ d->sizeHint = TQSize(); // invalidate size hint...
if ( d->ed )
d->updateLinedGeometry();
TQWidget::styleChange( s );